@@ -6,10 +6,11 @@ import math
 
 import matplotlib  # type: ignore
 import matplotlib.pyplot as plt  # type: ignore
+from matplotlib import font_manager
 from matplotlib.patches import Arc, Rectangle, PathPatch, Path  # type: ignore
 
 from .. import util
-from ..types import Capstyle, Joinstyle, Linestyle, BBox
+from ..types import Capstyle, Joinstyle, Linestyle, BBox, XY
 
 inline = 'inline' in matplotlib.get_backend()
 
@@ -88,9 +89,9 @@ class Figure:
                                  transform=self.ax.transData)
             patch.set_clip_path(cliprect)
 
-    def plot(self, x: float, y: float, color: str='black', ls: Linestyle='-',
-             lw: float=2, fill: str=None, capstyle: Capstyle='round',
-             joinstyle: Joinstyle='round', clip: BBox=None, zorder: int=2) -> None:
+    def plot(self, x: float, y: float, color: str = 'black', ls: Linestyle = '-',
+             lw: float = 2, fill: str = None, capstyle: Capstyle = 'round',
+             joinstyle: Joinstyle = 'round', clip: BBox = None, zorder: int = 2) -> None:
         ''' Plot a path '''
         p, = self.ax.plot(x, y, zorder=zorder, color=color, ls=ls, lw=lw,
                           solid_capstyle=fix_capstyle(capstyle),
@@ -100,11 +101,18 @@ class Figure:
             p, = self.ax.fill(x, y, color=fill, zorder=zorder-1)
             self.addclip(p, clip)
 
-    def text(self, s: str, x, y, color='black', fontsize=14, fontfamily='sans-serif',
-             mathfont=None,
-             rotation=0, halign='center', valign='center', rotation_mode='anchor',
-             clip: BBox=None, zorder=3) -> None:
+    def text(self, s: str, x: float, y: float, color: str = 'black',
+             fontsize: float = 14, fontfamily: str = 'sans-serif',
+             mathfont: str = None, rotation: float = 0,
+             halign: str = 'center', valign: str = 'center',
+             rotation_mode: str = 'anchor', clip: BBox = None, zorder=3) -> None:
         ''' Add text to the figure '''
+        if fontfamily.endswith('.ttf') or fontfamily.endswith('otf'):
+            if fontfamily not in [f.fname for f in font_manager.fontManager.ttflist]:
+                font_manager.fontManager.addfont(fontfamily)
+            idx = [f.fname for f in font_manager.fontManager.ttflist].index(fontfamily)
+            fontfamily = font_manager.fontManager.ttflist[idx].name
+
         t = self.ax.text(x, y, s, transform=self.ax.transData, color=color,
                          fontsize=fontsize-1.5, fontfamily=fontfamily,
                          math_fontfamily=mathfont,
@@ -113,9 +121,9 @@ class Figure:
                          zorder=zorder, clip_on=True)
         self.addclip(t, clip)
 
-    def poly(self, verts: Sequence[Sequence[float]], closed: bool=True,
-             color: str='black', fill: str=None, lw: float=2, ls: Linestyle='-', hatch: bool=False,
-             capstyle: Capstyle='round', joinstyle: Joinstyle='round', clip: BBox=None, zorder: int=1) -> None:
+    def poly(self, verts: Sequence[XY], closed: bool = True,
+             color: str = 'black', fill: str = None, lw: float = 2, ls: Linestyle = '-', hatch: bool = False,
+             capstyle: Capstyle = 'round', joinstyle: Joinstyle = 'round', clip: BBox = None, zorder: int = 1) -> None:
         ''' Draw a polynomial '''
         h = '///////' if hatch else None
         p = plt.Polygon(verts, closed=closed, ec=color,
@@ -125,17 +133,17 @@ class Figure:
         self.ax.add_patch(p)
         self.addclip(p, clip)
 
-    def circle(self, center: Sequence[float], radius: float, color: str='black', fill: str=None,
-               lw: float=2, ls: Linestyle='-', clip: BBox=None, zorder: int=1) -> None:
+    def circle(self, center: XY, radius: float, color: str = 'black', fill: str = None,
+               lw: float = 2, ls: Linestyle = '-', clip: BBox = None, zorder: int = 1) -> None:
         ''' Draw a circle '''
         circ = plt.Circle(xy=center, radius=radius, ec=color, fc=fill,
                           fill=fill is not None, lw=lw, ls=ls, zorder=zorder)
         self.ax.add_patch(circ)
         self.addclip(circ, clip)
 
-    def arrow(self, xy: Sequence[float], theta: float,
-              arrowwidth: float=.15, arrowlength: float=.25,
-              color: str='black', lw: float=2, clip: BBox=None, zorder: int=1) -> None:
+    def arrow(self, xy: XY, theta: float,
+              arrowwidth: float = .15, arrowlength: float = .25,
+              color: str = 'black', lw: float = 2, clip: BBox = None, zorder: int = 1) -> None:
         ''' Draw an arrowhead '''
         # Easier to skip Matplotlib's arrow or annotate methods and just draw a line
         # and a polygon.
@@ -156,10 +164,10 @@ class Figure:
         self.ax.add_patch(p)
         self.addclip(p, clip)
 
-    def bezier(self, p: Sequence[util.Point], color: str='black',
-               lw: float=2, ls: Linestyle='-', capstyle: Capstyle='round', zorder: int=1,
-               arrow: str=None, arrowlength: float=0.25, arrowwidth: float=0.15,
-               clip: BBox=None) -> None:
+    def bezier(self, p: Sequence[util.Point], color: str = 'black',
+               lw: float = 2, ls: Linestyle = '-', capstyle: Capstyle = 'round', zorder: int = 1,
+               arrow: str = None, arrowlength: float = 0.25, arrowwidth: float = 0.15,
+               clip: BBox = None) -> None:
         ''' Draw a cubic or quadratic bezier '''
         # Keep original points for arrow head
         # and adjust points for line so they don't extrude from arrows.
@@ -193,7 +201,7 @@ class Figure:
                            arrowwidth=arrowwidth, color=color, zorder=zorder)
             elif arrow.startswith('o'):
                 self.circle(p[0], radius=arrowwidth/2, color=color, fill=color, lw=0,
-                           clip=clip, zorder=zorder)
+                            clip=clip, zorder=zorder)
 
             if '>' in arrow:
                 delta = p[-1] - p[-2]
@@ -202,12 +210,12 @@ class Figure:
                            arrowwidth=arrowwidth, color=color, zorder=zorder)
             elif arrow.endswith('o'):
                 self.circle(p[-1], radius=arrowwidth/2, color=color, fill=color, lw=0,
-                           clip=clip, zorder=zorder)
+                            clip=clip, zorder=zorder)
 
-    def arc(self, center: Sequence[float], width: float, height: float,
-            theta1: float=0, theta2: float=90, angle: float=0,
-            color: str='black', lw: float=2, ls: Linestyle='-',
-            zorder: int=1, clip: BBox=None, arrow: str=None) -> None:
+    def arc(self, center: XY, width: float, height: float,
+            theta1: float = 0, theta2: float = 90, angle: float = 0,
+            color: str = 'black', lw: float = 2, ls: Linestyle = '-',
+            zorder: int = 1, clip: BBox = None, arrow: str = None) -> None:
         ''' Draw an arc or ellipse, with optional arrowhead '''
         arc = Arc(center, width=width, height=height, theta1=theta1,
                   theta2=theta2, angle=angle, color=color,
@@ -239,7 +247,7 @@ class Figure:
                               head_length=.25, color=color, zorder=zorder)
             self.addclip(a, clip)
 
-    def save(self, fname: str, transparent: bool=True, dpi: float=72) -> None:
+    def save(self, fname: str, transparent: bool = True, dpi: float = 72) -> None:
         ''' Save the figure to a file '''
         fig = self.getfig()
         fig.savefig(fname, bbox_inches='tight', transparent=transparent, dpi=dpi,
